==> Task-Perinci-0.07.tar.gz: Task-Perinci-0.07/lib/Task/Perinci.pm <==
package Task::Perinci;

our $VERSION = '0.07'; # VERSION

1;
# ABSTRACT: Install all Perinci:: modules


__END__
=pod

=head1 NAME

Task::Perinci - Install all Perinci:: modules

=head1 VERSION

version 0.07

=head1 DESCRIPTION

This task will install all Perinci:: modules.

=head1 TASK CONTENTS

=head2 Included modules

=head3 L<Perinci>

=head3 L<Perinci::Access::HTTP::Client>

=head3 L<Perinci::Access::HTTP::Server>

=head3 L<Perinci::Access::TCP::Client>

=head3 L<Perinci::Access::TCP::Server>

=head3 L<Perinci::BashComplete>

=head3 L<Perinci::Examples>

=head3 L<Perinci::Object>

=head3 L<Perinci::Sub::ConvertArgs::Array>

=head3 L<Perinci::Sub::DepChecker>

=head3 L<Perinci::Sub::Gen::AccessTable>

=head3 L<Perinci::Sub::Gen::AccessTable::DBI>

=head3 L<Perinci::Sub::Gen::Undoable>

=head3 L<Perinci::Sub::GetArgs::Argv>

=head3 L<Perinci::Sub::GetArgs::Array>

=head3 L<Perinci::Sub::property::drops_privilege>

=head3 L<Perinci::Sub::property::result_postfilter>

=head3 L<Perinci::Sub::property::retry>

=head3 L<Perinci::Sub::property::timeout>

=head3 L<Perinci::Sub::Wrapper>

=head3 L<Perinci::To::HTML>

=head3 L<Perinci::To::POD>

=head3 L<Perinci::To::Text>

=head3 L<Perinci::Use>

=head3 L<Pod::Weaver::Plugin::Perinci>

=head3 L<Riap>

=head3 L<Rinci>

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Task-Perinci-0.08.tar.gz: Task-Perinci-0.08/lib/Task/Perinci.pm <==
package Task::Perinci;

our $VERSION = '0.08'; # VERSION

1;
# ABSTRACT: Install all Perinci:: modules


__END__
=pod

=head1 NAME

Task::Perinci - Install all Perinci:: modules

=head1 VERSION

version 0.08

=head1 DESCRIPTION

This task will install all Perinci:: modules.

=head1 TASK CONTENTS

=head2 Included modules

=head3 L<Perinci>

=head3 L<Perinci::Access::HTTP::Client>

=head3 L<Perinci::Access::HTTP::Server>

=head3 L<Perinci::Access::Simple::Client>

=head3 L<Perinci::Access::Simple::Server::Pipe>

=head3 L<Perinci::Access::Simple::Server::Socket>

=head3 L<Perinci::BashComplete>

=head3 L<Perinci::Examples>

=head3 L<Perinci::Exporter>

=head3 L<Perinci::Object>

=head3 L<Perinci::Sub::ConvertArgs::Array>

=head3 L<Perinci::Sub::DepChecker>

=head3 L<Perinci::Sub::Gen::AccessTable>

=head3 L<Perinci::Sub::Gen::AccessTable::DBI>

=head3 L<Perinci::Sub::Gen::Undoable>

=head3 L<Perinci::Sub::GetArgs::Argv>

=head3 L<Perinci::Sub::GetArgs::Array>

=head3 L<Perinci::Sub::property::curry>

=head3 L<Perinci::Sub::property::dies_on_error>

=head3 L<Perinci::Sub::property::drops_privilege>

=head3 L<Perinci::Sub::property::result_postfilter>

=head3 L<Perinci::Sub::property::retry>

=head3 L<Perinci::Sub::property::timeout>

=head3 L<Perinci::Sub::Wrapper>

=head3 L<Perinci::To::HTML>

=head3 L<Perinci::To::POD>

=head3 L<Perinci::To::Text>

=head3 L<Perinci::Use>

=head3 L<Perinci::Util>

=head3 L<Pod::Weaver::Plugin::Perinci>

=head3 L<Riap>

=head3 L<Rinci>

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
